@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2015-2016 -- leonerd@leonerd.org.uk
 
 package Device::FTDI::I2C;
 
@@ -11,7 +11,7 @@ use base qw( Device::FTDI::MPSSE );
 
 use utf8;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 =head1 NAME
 
@@ -33,6 +33,8 @@ use Device::FTDI::MPSSE qw(
 
 use Future::Utils qw( repeat );
 
+use constant DEBUG => $ENV{PERL_FTDI_DEBUG} // 0;
+
 use constant {
     I2C_SCL     => (1<<0),
     I2C_SDA_OUT => (1<<1),
@@ -179,6 +181,8 @@ sub i2c_start
 {
     my $self = shift;
 
+    print STDERR "FTDI MPSSE I2C START\n" if DEBUG;
+
     my $f;
 
     # S&H delay
@@ -192,6 +196,8 @@ sub i2c_repeated_start
 {
     my $self = shift;
 
+    print STDERR "FTDI MPSSE I2C REPEAT-START\n" if DEBUG;
+
     # Release the lines without appearing as STOP
     $self->write_gpio( DBUS, HIGH, I2C_SDA_OUT ) for 1 .. 10;
     $self->write_gpio( DBUS, HIGH, I2C_SCL ) for 1 .. 10;
@@ -203,6 +209,8 @@ sub i2c_stop
 {
     my $self = shift;
 
+    print STDERR "FTDI MPSSE I2C STOP\n" if DEBUG;
+
     my $f;
 
     $self->write_gpio( DBUS, LOW, I2C_SDA_OUT );
@@ -219,6 +227,8 @@ sub i2c_send
     my $self = shift;
     my ( $data, $more_f ) = @_;
 
+    printf STDERR "FTDI MPSSE I2C SEND %v02X\n", $data if DEBUG;
+
     my $check = $self->{i2c_check_mode};
 
     repeat {
@@ -255,6 +265,8 @@ sub i2c_sendaddr
     my $self = shift;
     my ( $addr, $rd, $more_f ) = @_;
 
+    printf STDERR "FTDI MPSSE I2C ADDR %02X %s\n", $addr, $rd ? "R" : "W" if DEBUG;
+
     my $check = $self->{i2c_check_mode};
 
     $self->write_bytes( pack "C", $rd | $addr << 1 );
@@ -291,6 +303,9 @@ sub i2c_recv
         $f = $self->read_bytes( 1 )
             ->on_done( sub { $data_in .= $_[0] } );
 
+        $f->on_done( sub { printf STDERR "FTDI MPSSE I2C READ %v02X\n", $_[0] } ) if DEBUG;
+        $f->on_fail( sub { printf STDERR "FTDI MPSSE I2C READ FAILED\n" } ) if DEBUG;
+
         $self->write_bits( 1, chr( $ack ? LOW : HIGH ) );
         # Release SDA
         $self->write_gpio( DBUS, HIGH, I2C_SDA_OUT );
@@ -324,27 +339,46 @@ sub write
     $self->i2c_sendaddr( $addr, WRITE, \@more_f )
     ->then( sub {
         $self->i2c_send( $data, \@more_f )
-    })->then( sub {
-        my $f = $self->i2c_stop;
+    })->followed_by( sub {
+        my ( $f ) = @_;
+
+        $self->i2c_stop;
 
         return $f unless @more_f;
         Future->needs_all( @more_f )->then( sub { $f } );
     });
 }
 
+=head2 read
+
+    $data_in = $i2c->read( $addr, $len_in )->get
+
+Performs an I²C read operation to the chip at the given (7-bit) address
+value.
+
+The device sends a start condition, then a command to address the chip for
+reading. It then attempts to read up to the given number of bytes of input
+from the chip, sending an C<ACK> condition to all but the final byte, to which
+it sends C<NACK>, then finally a stop condition.
+
+=cut
+
+sub read
+{
+    my $self = shift;
+    my ( $addr, $len_in ) = @_;
+    $self->write_then_read( $addr, "", $len_in );
+}
+
 =head2 write_then_read
 
     $data_in = $i2c->write_then_read( $addr, $data_out, $len_in )->get
 
 Performs an I²C write operation followed by a read operation within the same
-transaction to the chip at the given (7-bit) address value.
-
-The device sends a start condition, then a command to address the chip for
-writing, followed by the bytes given in the data to output, then a repeated
-repeated start condition, then a command to address the chip for reading. It
-then attempts to read up to the given number of bytes of input from the chip,
-sending an C<ACK> condition to all but the final byte, to which it sends
-C<NACK>, and then finally a stop condition.
+transaction to the chip at the given (7-bit) address value. This is roughly
+equivalent to performing separate calls to L</write> and L</read> except that
+the two will be combined into a single I²C transaction using a repeated start
+condition.
 
 =cut
 
@@ -357,19 +391,26 @@ sub write_then_read
 
     my @more_f;
 
-    $self->i2c_sendaddr( $addr, WRITE, \@more_f )
-    ->then( sub {
-        $self->i2c_send( $data_out, \@more_f );
-    })->then( sub {
-        $self->i2c_repeated_start;
+    my $f = Future->done;
+
+    if( length $data_out ) {
+        $f = $self->i2c_sendaddr( $addr, WRITE, \@more_f )
+        ->then( sub {
+            $self->i2c_send( $data_out, \@more_f );
+        })->then( sub {
+            $self->i2c_repeated_start;
+        });
+    }
+
+    $f->then( sub {
         $self->i2c_sendaddr( $addr, READ, \@more_f )
     })->then( sub {
         $self->i2c_recv( $len_in );
-    })->then( sub {
-        my ( $data_in ) = @_;
+    })->followed_by( sub {
+        my ( $f ) = @_;
 
         Future->needs_all( $self->i2c_stop, @more_f )
-            ->then_done( $data_in );
+            ->then( sub { $f } );
     });
 }
 
